Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIError ¶
func NewAPIError ¶
type ErrorResponse ¶
type ErrorResponse struct {
// URI that identifies the problem type.
Type *string `json:"type,omitempty"`
// HTTP status code generated by the origin server for this occurrence of the problem.
Status *int64 `json:"status,omitempty"`
// Short, human-readable summary of the problem type.
Title *string `json:"title,omitempty"`
// Human-readable explanation specific to this occurrence of the problem.
Detail *string `json:"detail,omitempty"`
// API-specific error code to help the provider team classify the error.
Code *string `json:"code,omitempty"`
// URI that identifies this specific occurrence of the problem.
Instance *string `json:"instance,omitempty"`
HTTPMeta components.HTTPMetadata `json:"-"`
}
ErrorResponse - Problem Details object (RFC 9457) describing the error.
func (*ErrorResponse) Error ¶
func (e *ErrorResponse) Error() string
Click to show internal directories.
Click to hide internal directories.